<?php

namespace FiloBlu\Refilo\Console\Command;

use FiloBlu\Refilo\Model\Exporter\Translations;
use FiloBlu\Refilo\Model\Exporter\TranslationsFactory;
use FiloBlu\Refilo\Model\Importer\Translation;
use Magento\Framework\Console\CommandListInterface;
use Symfony\Component\Console\Command\Command;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;

/**
 * Class SyncTranslationCommand
 * @package FiloBlu\Refilo\Console\Command
 */
class SyncTranslationCommand extends Command
{
    /**
     * @var CommandListInterface[]
     */
    protected $commandList;
    /**
     * @var TranslationsFactory
     */
    private $translationsFactory;
    /**
     * @var Translation
     */
    private $translation;

    /**
     * SyncTranslationCommand constructor.
     * @param TranslationsFactory $translationsFactory
     * @param Translation $translation
     * @param string|null $name
     */
    public function __construct(
        TranslationsFactory $translationsFactory,
        Translation         $translation,
        string              $name = null
    )
    {
        parent::__construct($name);
        $this->translationsFactory = $translationsFactory;
        $this->translation = $translation;
    }

    /**
     * @inheritDoc
     */
    protected function configure()
    {
        $this->setName('refilo:translation:sync');
        $this->setDescription('Sync all syncable');
        parent::configure();
    }

    /**
     * Execute the command
     *
     * @param InputInterface $input
     * @param OutputInterface $output
     *
     * @return void
     */
    protected function execute(InputInterface $input, OutputInterface $output)
    {
        /** @var Translations $translation */
        $translation = $this->translationsFactory->create();

        foreach ($translation->getLocales() as $locale) {
            $this->translation->import($locale);
        }
    }

}
